@@ -11,7 +11,6 @@ import contextlib
 import logging
 import os
 import socket
-import time
 
 import attr
 import pytest
@@ -115,43 +114,17 @@ class CoverageContextPlugin:
         self.context.term()
         self.pusher = self.context = self.running = None
 
-    def get_unused_localhost_port(self, cached_seconds=10):
+    @staticmethod
+    def get_unused_localhost_port():
         """
         Return a random unused port on localhost
         """
-        if not isinstance(cached_seconds, (int, float)):
-            raise RuntimeError(
-                "The value of 'cached_seconds' needs to be an integer or a float, not {}".format(
-                    type(cached_seconds)
-                )
-            )
-        if cached_seconds < 0:
-            raise RuntimeError(
-                "The value of 'cached_seconds' needs to be a positive number, not {}".format(
-                    cached_seconds
-                )
-            )
-        try:
-            generated_ports = self.get_unused_localhost_port.__used_ports__
-            # Cleanup ports. The idea behind this call is so that two consecutive calls to this
-            # function don't return the same port just because the first call hasn't actually started
-            # using the port.
-            # It also makes this cache invalid after <cached_seconds> second
-            for port in list(generated_ports):
-                if generated_ports[port] <= time.time():
-                    generated_ports.pop(port)
-        except AttributeError:
-            generated_ports = self.get_unused_localhost_port.__used_ports__ = {}
-
         with contextlib.closing(
             socket.socket(family=socket.AF_INET, type=socket.SOCK_STREAM)
         ) as usock:
             usock.bind(("127.0.0.1", 0))
             port = usock.getsockname()[1]
-        if port not in generated_ports:
-            generated_ports[port] = time.time() + cached_seconds
             return port
-        return self.get_unused_localhost_port(cached_seconds=cached_seconds)
 
 
 @pytest.hookimpl(trylast=True)
@@ -169,7 +142,8 @@ def pytest_sessionstart(session):
     Start our plugin
     """
     _plugin = session.config.pluginmanager.get_plugin("coverage-context-plugin")
-    _plugin.start()
+    if _plugin:
+        _plugin.start()
 
 
 @pytest.hookimpl(trylast=True)
@@ -178,4 +152,5 @@ def pytest_sessionfinish(session):
     Stop our plugin
     """
     _plugin = session.config.pluginmanager.get_plugin("coverage-context-plugin")
-    _plugin.stop()
+    if _plugin:
+        _plugin.stop()
